==> spid_compliant_certificates-0.3.1.tar.gz: spid_compliant_certificates-0.3.1/spid_compliant_certificates/validator/checks/__init__.py <==
# Copyright 2021 Paolo Smiraglia <paolo.smiraglia@gmail.com>
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

from spid_compliant_certificates.validator.checks.basic_constraints import \
    basic_constraints  # noqa
from spid_compliant_certificates.validator.checks.certificate_policies import \
    certificate_policies  # noqa
from spid_compliant_certificates.validator.checks.digest_algorithm import \
    digest_algorithm  # noqa
from spid_compliant_certificates.validator.checks.key_type_and_size import \
    key_type_and_size  # noqa
from spid_compliant_certificates.validator.checks.key_usage import \
    key_usage  # noqa
from spid_compliant_certificates.validator.checks.subject_dn import \
    subject_dn  # noqa

_all_ = [
    'basic_constraints',
    'certificate_policies',
    'digest_algorithm',
    'key_type_and_size',
    'key_usage',
    'subject_dn',
]

==> spid_compliant_certificates-0.5.tar.gz: spid_compliant_certificates-0.5/spid_compliant_certificates/validator/checks/__init__.py <==
# Copyright 2021 Paolo Smiraglia <paolo.smiraglia@gmail.com>
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

from spid_compliant_certificates.validator.checks.basic_constraints import \
    basic_constraints  # noqa
from spid_compliant_certificates.validator.checks.certificate_policies import \
    certificate_policies  # noqa
from spid_compliant_certificates.validator.checks.digest_algorithm import \
    digest_algorithm  # noqa
from spid_compliant_certificates.validator.checks.key_type_and_size import \
    key_type_and_size  # noqa
from spid_compliant_certificates.validator.checks.key_usage import \
    key_usage  # noqa
from spid_compliant_certificates.validator.checks.subject_dn import \
    subject_dn  # noqa
from spid_compliant_certificates.validator.checks.time_validity import \
    not_expired  # noqa

_all_ = [
    'basic_constraints',
    'certificate_policies',
    'digest_algorithm',
    'key_type_and_size',
    'key_usage',
    'subject_dn',
    'not_expired'
]
